# py-canary-2

Forked from https://github.com/snjoetw/py-canary

Python API for Canary Security Camera.  This is used in [Home Assistant](https://home-assistant.io) but should be generic enough that can be used elsewhere.
